//---------.NET Sample Code 
//---------Bing Technologies Pty Ltd

//---------To upload files with full paths stored in files the following code can be used:

	sessId = getSessId();
	foreach (var f in files)
		uploadFile(sessId, f.ToString());
	endSession(sessId, false);

//---------in a class which also has the following members:

    private string hostURI = "https://www.easymail.com";
    private string account = "accountId";//your account id
    private string user = "user";//Bing portal user name
    private string pass = "pass";//Bing portal user password

    private string getSessId()
    {
        WebRequest request = GetWebRequest(hostURI + "/publicinterface/get_session_id.text?account=" + account, true);
        request.Method = "GET";
        string ret = null;
        using (WebResponse response = request.GetResponse())
        using (Stream data = response.GetResponseStream())
            ret = (new StreamReader(data)).ReadToEnd();
        return ret;
    }
    private void uploadFile(string sessId, string fName)
    {
        WebRequest request = GetWebRequest(hostURI + "/direct_upload/" + sessId + '/' + System.Uri.EscapeDataString(Path.GetFileName(fName)), false);
        request.Method = WebRequestMethods.Http.Put;
        switch (Path.GetExtension(fName))
        {
            case ".pdf": request.ContentType = "application/pdf"; break;
            case ".json": request.ContentType = "application/json"; break;
            case ".xml": request.ContentType = "application/xml"; break;
            default: request.ContentType = "application/octet-stream"; break;
        }
        using (FileStream fs = new FileStream(fName, FileMode.Open))
        {
            request.ContentLength = fs.Length;
            using (Stream outStream = request.GetRequestStream())
            {
                fs.CopyTo(outStream, 0x10000);
                outStream.Close();
            }
        }
        using (WebResponse response = request.GetResponse())
        {
            if (((HttpWebResponse)response).StatusCode != HttpStatusCode.Created)
                throw new Exception("Server returned bad status on file upload: " + ((HttpWebResponse)response).StatusDescription);
        }
    }
    private string endSession(string sessId, bool expectFailure)
    {
        WebRequest request = GetWebRequest(hostURI + "/publicinterface/end_session.text?session_id=" + sessId, true);
        request.Method = "GET";
        string ret = null;
        using(WebResponse response = request.GetResponse())
        using (Stream data = response.GetResponseStream())
        {
            ret = (new StreamReader(data)).ReadToEnd();
            response.Close();
            if ( !expectFailure && "OK" != ret.Substring(0, 2))
                throw new Exception("EndSession returned unexpected result. Response:\n" + ret);
        }
        return ret;
    }

    private WebRequest GetWebRequest(string url, bool addCreds)
    {
        WebRequest request = WebRequest.Create(new Uri(url));
       if (addCreds && !string.IsNullOrEmpty(user))
        {
            CredentialCache myCache = new CredentialCache();
            myCache.Add(new Uri(hostURI), "Digest", new NetworkCredential(user, pass, "bingmail.com.au"));
            request.Credentials = myCache;
            request.PreAuthenticate = true;
        }
        ((HttpWebRequest)request).UserAgent = ".NET Test Client";//user agent name
        return request;
    }